==> material__slider-4.0.0.jar: META-INF/resources/webjars/material__slider/4.0.0/component.d.ts <==
/**
 * @license
 * Copyright 2017 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import { MDCComponent } from '@material/base/component';
import { MDCSliderFoundation } from './foundation';
export declare class MDCSlider extends MDCComponent<MDCSliderFoundation> {
    static attachTo(root: Element): MDCSlider;
    protected root_: HTMLElement;
    private thumbContainer_;
    private track_;
    private pinValueMarker_;
    private trackMarkerContainer_;
    value: number;
    min: number;
    max: number;
    step: number;
    disabled: boolean;
    initialize(): void;
    getDefaultFoundation(): MDCSliderFoundation;
    initialSyncWithDOM(): void;
    layout(): void;
    stepUp(amount?: number): void;
    stepDown(amount?: number): void;
    private parseFloat_;
}

==> material__slider-6.0.0.jar: META-INF/resources/webjars/material__slider/6.0.0/component.d.ts <==
/**
 * @license
 * Copyright 2017 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
import { MDCComponent } from '@material/base/component';
import { MDCSliderFoundation } from './foundation';
export declare class MDCSlider extends MDCComponent<MDCSliderFoundation> {
    static attachTo(root: Element): MDCSlider;
    protected root_: HTMLElement;
    private thumbContainer_;
    private track_;
    private pinValueMarker_;
    private trackMarkerContainer_;
    get value(): number;
    set value(value: number);
    get min(): number;
    set min(min: number);
    get max(): number;
    set max(max: number);
    get step(): number;
    set step(step: number);
    get disabled(): boolean;
    set disabled(disabled: boolean);
    initialize(): void;
    getDefaultFoundation(): MDCSliderFoundation;
    initialSyncWithDOM(): void;
    layout(): void;
    stepUp(amount?: number): void;
    stepDown(amount?: number): void;
    private parseFloat_;
}
